==> presto-jdbc-0.288.1-sources.jar: com/facebook/presto/jdbc/internal/javax/annotation/concurrent/GuardedBy.java <==
/*
 * Copyright (c) 2005 Brian Goetz
 * Released under the Creative Commons Attribution License
 *   (http://creativecommons.org/licenses/by/2.5)
 * Official home: http://www.jcip.net
 */
package com.facebook.presto.jdbc.internal.com.facebook.presto.jdbc.internal.javax.annotation.concurrent;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * The field or method to which this annotation is applied can only be accessed
 * when holding a particular lock, which may be a built-in (synchronization)
 * lock, or may be an explicit {@link java.util.concurrent.locks.Lock}.
 * <p>
 * The argument determines which lock guards the annotated field or method:
 * <ul>
 * <li>this : The string literal "this" means that this field is guarded by the class in which it is defined.
 * <li>class-name.this : For inner classes, it may be necessary to disambiguate 'this';
 * the class-name.this designation allows you to specify which 'this' reference is intended
 * <li>itself : For reference fields only; the object to which the field refers.
 * <li>field-name : The lock object is referenced by the (instance or static) field specified by field-name.
 * <li>class-name.field-name : The lock object is reference by the static field specified by class-name.field-name.
 * <li>method-name() : The lock object is returned by calling the named nil-ary method.
 * <li>class-name.class : The Class object for the specified class should be used as the lock object.
 * </ul>
 */
@Target( { ElementType.FIELD, ElementType.METHOD })
@Retention(RetentionPolicy.CLASS)
public @interface GuardedBy {
    String value();
}

==> presto-jdbc-0.294-sources.jar: com/facebook/presto/jdbc/internal/javax/annotation/concurrent/GuardedBy.java <==
/*
 * Copyright (c) 2005 Brian Goetz
 * Released under the Creative Commons Attribution License
 *   (http://creativecommons.org/licenses/by/2.5)
 * Official home: http://www.jcip.net
 */
package com.facebook.presto.jdbc.internal.javax.annotation.concurrent;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * The field or method to which this annotation is applied can only be accessed
 * when holding a particular lock, which may be a built-in (synchronization)
 * lock, or may be an explicit {@link java.util.concurrent.locks.Lock}.
 * <p>
 * The argument determines which lock guards the annotated field or method:
 * <ul>
 * <li>this : The string literal "this" means that this field is guarded by the class in which it is defined.
 * <li>class-name.this : For inner classes, it may be necessary to disambiguate 'this';
 * the class-name.this designation allows you to specify which 'this' reference is intended
 * <li>itself : For reference fields only; the object to which the field refers.
 * <li>field-name : The lock object is referenced by the (instance or static) field specified by field-name.
 * <li>class-name.field-name : The lock object is reference by the static field specified by class-name.field-name.
 * <li>method-name() : The lock object is returned by calling the named nil-ary method.
 * <li>class-name.class : The Class object for the specified class should be used as the lock object.
 * </ul>
 */
@Target( { ElementType.FIELD, ElementType.METHOD })
@Retention(RetentionPolicy.CLASS)
public @interface GuardedBy {
    String value();
}
